==> Sylius-v1.13.6.zip: Sylius-1.13.6/README.md <==
<h1 align="center">
    <a href="https://sylius.com/github-readme/link/" target="_blank">
        <img src="https://sylius.com/assets/github-readme.png?cloud" />
    </a>
</h1>

Sylius is an Open Source eCommerce framework on top of [**Symfony**](https://symfony.com). 

The highest quality of code, strong testing culture, built-in Agile (BDD) workflow and exceptional flexibility make it the best solution for applications tailored to your business requirements. 
Powerful REST API allows for easy integrations and creating unique customer experience on any device.

We're using full-stack Behavior-Driven-Development, with [phpspec](https://phpspec.net) and [Behat](https://behat.org).

Enjoy being an eCommerce Developer again!

<img src="https://sylius.com/assets/readme/readme-main.png" />

⚙️ Installation
--------------

[Install Sylius](https://docs.sylius.com/en/latest/book/installation/installation.html) with Composer (see [requirements details](https://docs.sylius.com/en/latest/book/installation/requirements.html)).

Follow the [Getting started with Sylius tutorial](https://docs.sylius.com/en/latest/getting-started-with-sylius/index.html)!

📖 Documentation
----------------
 
Documentation is available at [docs.sylius.com](https://docs.sylius.com).

➕ Sylius Plus
--------------

<a href="https://sylius.com/plus/" target="_blank">
    <img src="https://sylius.com/assets/readme/readme-plus.png" />
</a>

[Sylius Plus](https://sylius.com/plus/) offers modular features like **OnePageCheckout** and a **B2B suite**, alongside advanced capabilities such as 
multi-store management, partial order fulfillment, smooth returns handling, a loyalty system and multi-source inventory. 
Pick and choose the modules you need to supercharge your eCommerce projects effortlessly.

🤝 Community
------------

Get Sylius support on [Slack](https://sylius.com/slack) or [Stack Overflow](https://stackoverflow.com/questions/tagged/sylius)
or get professional **SLA-backed support and Project Success Assistance** with Sylius Plus license! [Learn more.](https://sylius.com/plus/)

Stay updated by following our [Twitter](https://twitter.com/Sylius) and [Facebook](https://www.facebook.com/SyliusEcommerce/).

Would like to help us and build the most developer-friendly eCommerce framework? Start from reading our [Contributing Guide](https://docs.sylius.com/en/latest/book/index.html#contributing)!

👮 Security issues
------------------

If you think that you have found a security issue in Sylius, please do not use the issue tracker and do not post it publicly. 
Instead, all security issues must be sent to `security@sylius.com`.

📦 Plugins and Extensions: Sylius Store
---------------------------------------

<a href="https://store.sylius.com/" target="_blank">
    <img src="https://sylius.com/assets/readme/readme-store.png" />
</a>
   
You can find Sylius plugins on [our Sylius Store](https://sylius.com/plugins/) which is a Marketplace with Sylius extensions. 

Or search for [packages marked as *sylius-plugin*](https://packagist.org/explore/?type=sylius-plugin) on Packagist.

📃 License
----------

Sylius is completely free and released under the [MIT License](https://github.com/Sylius/Sylius/blob/master/LICENSE).

✍️ Authors
---------

Sylius was originally created by [Paweł Jędrzejewski](https://pjedrzejewski.com).

Kudos to all Sylius contributors 🙏

[![](https://github.com/pamil.png?size=40)](https://github.com/pamil)
[![](https://github.com/pjedrzejewski.png?size=40)](https://github.com/pjedrzejewski)
[![](https://github.com/Zales0123.png?size=40)](https://github.com/Zales0123)
[![](https://github.com/GSadee.png?size=40)](https://github.com/GSadee)
[![](https://github.com/lchrusciel.png?size=40)](https://github.com/lchrusciel)
[![](https://github.com/CoderMaggie.png?size=40)](https://github.com/CoderMaggie)
[![](https://github.com/Arminek.png?size=40)](https://github.com/Arminek)
[![](https://github.com/tuka217.png?size=40)](https://github.com/tuka217)
[![](https://github.com/NoResponseMate.png?size=40)](https://github.com/NoResponseMate)
[![](https://github.com/stloyd.png?size=40)](https://github.com/stloyd)
[![](https://github.com/umpirsky.png?size=40)](https://github.com/umpirsky)
[![](https://github.com/winzou.png?size=40)](https://github.com/winzou)
[![](https://github.com/Tomanhez.png?size=40)](https://github.com/Tomanhez)
[![](https://github.com/michalmarcinkowski.png?size=40)](https://github.com/michalmarcinkowski)
[![](https://github.com/AdamKasp.png?size=40)](https://github.com/AdamKasp)
[![](https://github.com/arnolanglade.png?size=40)](https://github.com/arnolanglade)
[![](https://github.com/jjanvier.png?size=40)](https://github.com/jjanvier)
[![](https://github.com/kayue.png?size=40)](https://github.com/kayue)
[![](https://github.com/stefandoorn.png?size=40)](https://github.com/stefandoorn)
[![](https://github.com/piotrantosik.png?size=40)](https://github.com/piotrantosik)
[![](https://github.com/Richtermeister.png?size=40)](https://github.com/Richtermeister)
[![](https://github.com/kulczy.png?size=40)](https://github.com/kulczy)
[![](https://github.com/koemeet.png?size=40)](https://github.com/koemeet)
[![](https://github.com/oallain.png?size=40)](https://github.com/oallain)
[![](https://github.com/loic425.png?size=40)](https://github.com/loic425)
[![](https://github.com/bendavies.png?size=40)](https://github.com/bendavies)
[![](https://github.com/aramalipoor.png?size=40)](https://github.com/aramalipoor)
[![](https://github.com/amenophis.png?size=40)](https://github.com/amenophis)
[![](https://github.com/loicmobizel.png?size=40)](https://github.com/loicmobizel)
[![](https://github.com/mamazu.png?size=40)](https://github.com/mamazu)
[![](https://github.com/loevgaard.png?size=40)](https://github.com/loevgaard)
[![](https://github.com/makasim.png?size=40)](https://github.com/makasim)
[![](https://github.com/gperdomor.png?size=40)](https://github.com/gperdomor)
[![](https://github.com/arti0090.png?size=40)](https://github.com/arti0090)
[![](https://github.com/liverbool.png?size=40)](https://github.com/liverbool)
[![](https://github.com/mmenozzi.png?size=40)](https://github.com/mmenozzi)
[![](https://github.com/psyray.png?size=40)](https://github.com/psyray)
[![](https://github.com/mbabker.png?size=40)](https://github.com/mbabker)
[![](https://github.com/peteward.png?size=40)](https://github.com/peteward)
[![](https://github.com/adamelso.png?size=40)](https://github.com/adamelso)
[![](https://github.com/igormukhingmailcom.png?size=40)](https://github.com/igormukhingmailcom)
[![](https://github.com/antonioperic.png?size=40)](https://github.com/antonioperic)
[![](https://github.com/elliot.png?size=40)](https://github.com/elliot)
[![](https://github.com/agounaris.png?size=40)](https://github.com/agounaris)
[![](https://github.com/Prometee.png?size=40)](https://github.com/Prometee)
[![](https://github.com/l3l0.png?size=40)](https://github.com/l3l0)
[![](https://github.com/inssein.png?size=40)](https://github.com/inssein)
[![](https://github.com/loevstroem.png?size=40)](https://github.com/loevstroem)
[![](https://github.com/pborreli.png?size=40)](https://github.com/pborreli)
[![](https://github.com/gorkalaucirica.png?size=40)](https://github.com/gorkalaucirica)
[![](https://github.com/gabiudrescu.png?size=40)](https://github.com/gabiudrescu)
[![](https://github.com/cordoval.png?size=40)](https://github.com/cordoval)
[![](https://github.com/EmiiKhaos.png?size=40)](https://github.com/EmiiKhaos)
[![](https://github.com/venyii.png?size=40)](https://github.com/venyii)
[![](https://github.com/nakashu.png?size=40)](https://github.com/nakashu)
[![](https://github.com/LucaGallinari.png?size=40)](https://github.com/LucaGallinari)
[![](https://github.com/vvasiloi.png?size=40)](https://github.com/vvasiloi)
[![](https://github.com/teohhanhui.png?size=40)](https://github.com/teohhanhui)
[![](https://github.com/jacquesbh.png?size=40)](https://github.com/jacquesbh)
[![](https://github.com/diimpp.png?size=40)](https://github.com/diimpp)
[![](https://github.com/sweoggy.png?size=40)](https://github.com/sweoggy)
[![](https://github.com/bartoszpietrzak1994.png?size=40)](https://github.com/bartoszpietrzak1994)
[![](https://github.com/psihius.png?size=40)](https://github.com/psihius)
[![](https://github.com/okwinza.png?size=40)](https://github.com/okwinza)
[![](https://github.com/bitbager.png?size=40)](https://github.com/bitbager)
[![](https://github.com/alcaeus.png?size=40)](https://github.com/alcaeus)
[![](https://github.com/ahmadrabie.png?size=40)](https://github.com/ahmadrabie)
[![](https://github.com/coudenysj.png?size=40)](https://github.com/coudenysj)
[![](https://github.com/mykehsd.png?size=40)](https://github.com/mykehsd)
[![](https://github.com/gonzalovilaseca.png?size=40)](https://github.com/gonzalovilaseca)
[![](https://github.com/4c0n.png?size=40)](https://github.com/4c0n)
[![](https://github.com/tvlooy.png?size=40)](https://github.com/tvlooy)
[![](https://github.com/dantleech.png?size=40)](https://github.com/dantleech)
[![](https://github.com/cdaguerre.png?size=40)](https://github.com/cdaguerre)
[![](https://github.com/Strontium-90.png?size=40)](https://github.com/Strontium-90)
[![](https://github.com/JaisDK.png?size=40)](https://github.com/JaisDK)
[![](https://github.com/pix-art.png?size=40)](https://github.com/pix-art)
[![](https://github.com/dunglas.png?size=40)](https://github.com/dunglas)
[![](https://github.com/SirDomin.png?size=40)](https://github.com/SirDomin)
[![](https://github.com/peterukena.png?size=40)](https://github.com/peterukena)
[![](https://github.com/tchapi.png?size=40)](https://github.com/tchapi)
[![](https://github.com/laurent35240.png?size=40)](https://github.com/laurent35240)
[![](https://github.com/jdeveloper.png?size=40)](https://github.com/jdeveloper)
[![](https://github.com/TomasVotruba.png?size=40)](https://github.com/TomasVotruba)

... and others!


See the full list of [contributors from our awesome community](https://github.com/Sylius/Sylius/contributors).

==> Sylius-v1.13.7.zip: Sylius-1.13.7/README.md <==
<h1 align="center">
    <a href="https://sylius.com/github-readme/link/" target="_blank">
        <img src="https://sylius.com/assets/github-readme.png?syliuscon24" />
    </a>
</h1>

Sylius is an Open Source eCommerce framework on top of [**Symfony**](https://symfony.com). 

The highest quality of code, strong testing culture, built-in Agile (BDD) workflow and exceptional flexibility make it the best solution for applications tailored to your business requirements. 
Powerful REST API allows for easy integrations and creating unique customer experience on any device.

We're using full-stack Behavior-Driven-Development, with [phpspec](https://phpspec.net) and [Behat](https://behat.org).

Enjoy being an eCommerce Developer again!

<img src="https://sylius.com/assets/readme/readme-main.png" />

⚙️ Installation
--------------

[Install Sylius](https://docs.sylius.com/en/latest/book/installation/installation.html) with Composer (see [requirements details](https://docs.sylius.com/en/latest/book/installation/requirements.html)).

Follow the [Getting started with Sylius tutorial](https://docs.sylius.com/en/latest/getting-started-with-sylius/index.html)!

📖 Documentation
----------------
 
Documentation is available at [docs.sylius.com](https://docs.sylius.com).

➕ Sylius Plus
--------------

<a href="https://sylius.com/plus/" target="_blank">
    <img src="https://sylius.com/assets/readme/readme-plus.png" />
</a>

[Sylius Plus](https://sylius.com/plus/) offers modular features like **OnePageCheckout** and a **B2B suite**, alongside advanced capabilities such as 
multi-store management, partial order fulfillment, smooth returns handling, a loyalty system and multi-source inventory. 
Pick and choose the modules you need to supercharge your eCommerce projects effortlessly.

🤝 Community
------------

Get Sylius support on [Slack](https://sylius.com/slack) or [Stack Overflow](https://stackoverflow.com/questions/tagged/sylius)
or get professional **SLA-backed support and Project Success Assistance** with Sylius Plus license! [Learn more.](https://sylius.com/plus/)

Stay updated by following our [Twitter](https://twitter.com/Sylius) and [Facebook](https://www.facebook.com/SyliusEcommerce/).

Would like to help us and build the most developer-friendly eCommerce framework? Start from reading our [Contributing Guide](https://docs.sylius.com/en/latest/book/index.html#contributing)!

👮 Security issues
------------------

If you think that you have found a security issue in Sylius, please do not use the issue tracker and do not post it publicly. 
Instead, all security issues must be sent to `security@sylius.com`.

📦 Plugins and Extensions: Sylius Store
---------------------------------------

<a href="https://store.sylius.com/" target="_blank">
    <img src="https://sylius.com/assets/readme/readme-store.png" />
</a>
   
You can find Sylius plugins on [our Sylius Store](https://sylius.com/plugins/) which is a Marketplace with Sylius extensions. 

Or search for [packages marked as *sylius-plugin*](https://packagist.org/explore/?type=sylius-plugin) on Packagist.

📃 License
----------

Sylius is completely free and released under the [MIT License](https://github.com/Sylius/Sylius/blob/master/LICENSE).

✍️ Authors
---------

Sylius was originally created by [Paweł Jędrzejewski](https://pjedrzejewski.com).

Kudos to all Sylius contributors 🙏

[![](https://github.com/pamil.png?size=40)](https://github.com/pamil)
[![](https://github.com/pjedrzejewski.png?size=40)](https://github.com/pjedrzejewski)
[![](https://github.com/Zales0123.png?size=40)](https://github.com/Zales0123)
[![](https://github.com/GSadee.png?size=40)](https://github.com/GSadee)
[![](https://github.com/lchrusciel.png?size=40)](https://github.com/lchrusciel)
[![](https://github.com/CoderMaggie.png?size=40)](https://github.com/CoderMaggie)
[![](https://github.com/Arminek.png?size=40)](https://github.com/Arminek)
[![](https://github.com/tuka217.png?size=40)](https://github.com/tuka217)
[![](https://github.com/NoResponseMate.png?size=40)](https://github.com/NoResponseMate)
[![](https://github.com/stloyd.png?size=40)](https://github.com/stloyd)
[![](https://github.com/umpirsky.png?size=40)](https://github.com/umpirsky)
[![](https://github.com/winzou.png?size=40)](https://github.com/winzou)
[![](https://github.com/Tomanhez.png?size=40)](https://github.com/Tomanhez)
[![](https://github.com/michalmarcinkowski.png?size=40)](https://github.com/michalmarcinkowski)
[![](https://github.com/AdamKasp.png?size=40)](https://github.com/AdamKasp)
[![](https://github.com/arnolanglade.png?size=40)](https://github.com/arnolanglade)
[![](https://github.com/jjanvier.png?size=40)](https://github.com/jjanvier)
[![](https://github.com/kayue.png?size=40)](https://github.com/kayue)
[![](https://github.com/stefandoorn.png?size=40)](https://github.com/stefandoorn)
[![](https://github.com/piotrantosik.png?size=40)](https://github.com/piotrantosik)
[![](https://github.com/Richtermeister.png?size=40)](https://github.com/Richtermeister)
[![](https://github.com/kulczy.png?size=40)](https://github.com/kulczy)
[![](https://github.com/koemeet.png?size=40)](https://github.com/koemeet)
[![](https://github.com/oallain.png?size=40)](https://github.com/oallain)
[![](https://github.com/loic425.png?size=40)](https://github.com/loic425)
[![](https://github.com/bendavies.png?size=40)](https://github.com/bendavies)
[![](https://github.com/aramalipoor.png?size=40)](https://github.com/aramalipoor)
[![](https://github.com/amenophis.png?size=40)](https://github.com/amenophis)
[![](https://github.com/loicmobizel.png?size=40)](https://github.com/loicmobizel)
[![](https://github.com/mamazu.png?size=40)](https://github.com/mamazu)
[![](https://github.com/loevgaard.png?size=40)](https://github.com/loevgaard)
[![](https://github.com/makasim.png?size=40)](https://github.com/makasim)
[![](https://github.com/gperdomor.png?size=40)](https://github.com/gperdomor)
[![](https://github.com/arti0090.png?size=40)](https://github.com/arti0090)
[![](https://github.com/liverbool.png?size=40)](https://github.com/liverbool)
[![](https://github.com/mmenozzi.png?size=40)](https://github.com/mmenozzi)
[![](https://github.com/psyray.png?size=40)](https://github.com/psyray)
[![](https://github.com/mbabker.png?size=40)](https://github.com/mbabker)
[![](https://github.com/peteward.png?size=40)](https://github.com/peteward)
[![](https://github.com/adamelso.png?size=40)](https://github.com/adamelso)
[![](https://github.com/igormukhingmailcom.png?size=40)](https://github.com/igormukhingmailcom)
[![](https://github.com/antonioperic.png?size=40)](https://github.com/antonioperic)
[![](https://github.com/elliot.png?size=40)](https://github.com/elliot)
[![](https://github.com/agounaris.png?size=40)](https://github.com/agounaris)
[![](https://github.com/Prometee.png?size=40)](https://github.com/Prometee)
[![](https://github.com/l3l0.png?size=40)](https://github.com/l3l0)
[![](https://github.com/inssein.png?size=40)](https://github.com/inssein)
[![](https://github.com/loevstroem.png?size=40)](https://github.com/loevstroem)
[![](https://github.com/pborreli.png?size=40)](https://github.com/pborreli)
[![](https://github.com/gorkalaucirica.png?size=40)](https://github.com/gorkalaucirica)
[![](https://github.com/gabiudrescu.png?size=40)](https://github.com/gabiudrescu)
[![](https://github.com/cordoval.png?size=40)](https://github.com/cordoval)
[![](https://github.com/EmiiKhaos.png?size=40)](https://github.com/EmiiKhaos)
[![](https://github.com/venyii.png?size=40)](https://github.com/venyii)
[![](https://github.com/nakashu.png?size=40)](https://github.com/nakashu)
[![](https://github.com/LucaGallinari.png?size=40)](https://github.com/LucaGallinari)
[![](https://github.com/vvasiloi.png?size=40)](https://github.com/vvasiloi)
[![](https://github.com/teohhanhui.png?size=40)](https://github.com/teohhanhui)
[![](https://github.com/jacquesbh.png?size=40)](https://github.com/jacquesbh)
[![](https://github.com/diimpp.png?size=40)](https://github.com/diimpp)
[![](https://github.com/sweoggy.png?size=40)](https://github.com/sweoggy)
[![](https://github.com/bartoszpietrzak1994.png?size=40)](https://github.com/bartoszpietrzak1994)
[![](https://github.com/psihius.png?size=40)](https://github.com/psihius)
[![](https://github.com/okwinza.png?size=40)](https://github.com/okwinza)
[![](https://github.com/bitbager.png?size=40)](https://github.com/bitbager)
[![](https://github.com/alcaeus.png?size=40)](https://github.com/alcaeus)
[![](https://github.com/ahmadrabie.png?size=40)](https://github.com/ahmadrabie)
[![](https://github.com/coudenysj.png?size=40)](https://github.com/coudenysj)
[![](https://github.com/mykehsd.png?size=40)](https://github.com/mykehsd)
[![](https://github.com/gonzalovilaseca.png?size=40)](https://github.com/gonzalovilaseca)
[![](https://github.com/4c0n.png?size=40)](https://github.com/4c0n)
[![](https://github.com/tvlooy.png?size=40)](https://github.com/tvlooy)
[![](https://github.com/dantleech.png?size=40)](https://github.com/dantleech)
[![](https://github.com/cdaguerre.png?size=40)](https://github.com/cdaguerre)
[![](https://github.com/Strontium-90.png?size=40)](https://github.com/Strontium-90)
[![](https://github.com/JaisDK.png?size=40)](https://github.com/JaisDK)
[![](https://github.com/pix-art.png?size=40)](https://github.com/pix-art)
[![](https://github.com/dunglas.png?size=40)](https://github.com/dunglas)
[![](https://github.com/SirDomin.png?size=40)](https://github.com/SirDomin)
[![](https://github.com/peterukena.png?size=40)](https://github.com/peterukena)
[![](https://github.com/tchapi.png?size=40)](https://github.com/tchapi)
[![](https://github.com/laurent35240.png?size=40)](https://github.com/laurent35240)
[![](https://github.com/jdeveloper.png?size=40)](https://github.com/jdeveloper)
[![](https://github.com/TomasVotruba.png?size=40)](https://github.com/TomasVotruba)

... and others!


See the full list of [contributors from our awesome community](https://github.com/Sylius/Sylius/contributors).
